| .dt2_detect_extensions | R Documentation |
Scans the options list for keys that imply certain extensions.
For example, buttons implies Buttons, select implies Select, etc.
.dt2_detect_extensions(options)
options |
DataTables options list |
character vector of detected extension names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.