dot-npm_latest_in_range: Fetch the latest version of an npm package within a version...

.npm_latest_in_rangeR Documentation

Fetch the latest version of an npm package within a version prefix

Description

Queries the full package metadata from npm and extracts all version strings, then returns the highest version that starts with prefix.

Usage

.npm_latest_in_range(pkg, prefix)

Arguments

pkg

npm package name

prefix

version prefix, e.g. "3." or "0.2."

Value

version string or NA


DT2 documentation built on June 14, 2026, 9:06 a.m.