| .npm_latest_in_range | R Documentation |
Queries the full package metadata from npm and extracts all version
strings, then returns the highest version that starts with prefix.
.npm_latest_in_range(pkg, prefix)
pkg |
npm package name |
prefix |
version prefix, e.g. |
version string or NA
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.