Configure DataTables Buttons and (optionally) move them to a custom container
Source:R/dt2_buttons.R
dt2_buttons.RdConfigure DataTables Buttons and (optionally) move them to a custom container
Arguments
- options
A DT2
optionslist you are building.Character vector with button names (e.g.
"copyHtml5","csvHtml5","excelHtml5","pdfHtml5","print"). You can also pass a list with full button objects.- target
Optional CSS selector (e.g.
"#btn-slot"or".my-toolbar") to receive the buttons container. If provided, DT2 will move the rendered buttons to that container after init.