| dt2_deps | R Documentation |
Constructs the dependency list dynamically based on the requested extensions. Only loads CSS/JS for selected extensions, keeping the page lightweight.
dt2_deps(
bs = c("bootstrap5", "core"),
include_bs = TRUE,
extensions = character()
)
bs |
|
include_bs |
Logical; if TRUE and |
extensions |
Character vector of extension names (e.g., |
All version numbers are read from .dt2_lib_versions() (defined in
dt2_check_updates.R) so there is a single source of truth for versions.
List of htmlDependency() objects in correct load order.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.